%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                 %
%  This file is in two parts                                      %
%    the top part is a direct copy of cmspaper.cls                %
%    the bottom part contains additions...(L. Taylor,  Feb 2001)  %
%                                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Name:     cmspaper.cls                                         %
%                                                                 %
%  Purpose:  Set LaTeX parameters for CMS note.                   %
%                                                                 %
%  This files is based on the Document Style 'CERNART'            %
%  by  Michel Goossens CN/ASD                                     %
%                                                                 %
%   - requires packages: graphics                                 %
%   - special treatment of title page                             %
%                                                                 %
%  Last mod : 25.11.1996                                          %
%  Updated for new CMS logo May 97 / JPP                          %
%                                                                 %
%  Grzegorz Wrochna, CERN/PPE                                     %
%                                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\def\fileversion{0.4}\def\filedate{25 Nov. 1996}
\typeout{CMS paper style Version <\fileversion>, <\filedate>}
\typeout{based on Document Style 'CERNART' Version <2.1>, <1 May 1995>}
% -------------------------------- identification ---------------------------
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cmspaper}[1996/11/25]
% ---------------------------  declaration of options --
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
% ----------------------------  execution of options ------------------------
\ProcessOptions
% --------------------------------package loading ---------------------------
\LoadClass{article}
 
%%%%%%%% page size to be printable on both A4 and US Letter %%%%%%%

\setlength{\hoffset}{-1in}
\setlength{\voffset}{-1in}
\setlength{\oddsidemargin}{25mm}
\setlength{\evensidemargin}{25mm}
\setlength{\marginparwidth}{25mm}
\setlength{\marginparsep}{\baselineskip}
\setlength{\topmargin}{20mm}
\setlength{\headheight}{0mm}
\setlength{\headsep}{0mm}
\setlength{\footskip}{6mm}
\setlength{\textwidth}{16cm}
\ifcase \@ptsize
%JPP-\setlength{\textheight}{58\baselineskip}
     \setlength{\textheight}{57\baselineskip}
\or
%JPP-\setlength{\textheight}{52\baselineskip}
     \setlength{\textheight}{51\baselineskip}
\or 
%JPP-\setlength{\textheight}{47\baselineskip}
     \setlength{\textheight}{46\baselineskip}
\fi
\addtolength{\textheight}{\topskip}

%%%%% floats handling parameters for better placing of figures %%%%%%%
\renewcommand{\topfraction}{1.0}
\renewcommand{\dbltopfraction}{1.0}
\renewcommand{\bottomfraction}{1.0}
\renewcommand{\textfraction}{0.2}
\setlength{\intextsep}{6pt}
\setlength{\floatsep}{6pt}
\setlength{\textfloatsep}{6pt}
\setlength{\dblfloatsep}{6pt}
\setlength{\dbltextfloatsep}{6pt}

%%%%%%%%%%%%%%%% nonindented paragraphs %%%%%%%%%%%%%%%
\setlength{\parindent}{0pt}
\setlength{\parskip}{0.5\baselineskip}
 
%%%%%%%%%%%%%%%%%%%%% section headings %%%%%%%%%%%%%%%%%%%%%%%%%%

\def\section{\@startsection {section}{1}{\z@}%
{ 1\baselineskip plus  .5\baselineskip minus  .25\baselineskip}%
{+0.1pt plus +0.1pt minus +0.1pt}{\reset@font\Large\bfseries}}
 
\def\subsection{\@startsection{subsection}{2}{\z@}%
{ 1\baselineskip plus  .5\baselineskip minus  .25\baselineskip}%
{+0.1pt plus +0.1pt minus +0.1pt}{\reset@font\large\bfseries}}
 
\def\subsubsection{\@startsection{subsubsection}{3}{\z@}%
{ 1\baselineskip plus  .5\baselineskip minus  .25\baselineskip}%
{+0.1pt plus +0.1pt minus +0.1pt}{\reset@font\normalsize\bfseries}}

%%%%%%%%%%%%%%%% define PostScript fonts %%%%%%%%%%%%%%%
  \renewcommand{\sfdefault}{phv}        % sansserif  = helvetica
  \renewcommand{\rmdefault}{ptm}        % roman      = times
  \renewcommand{\ttdefault}{pcr}        % typewriter = courier
  \newcommand{\hm}{\sf}                 % helvetica medium 
  \newcommand{\hb}{\bfseries\sffamily}  % helvetica bold
  \newcommand{\Hb}{\hb\fontsize{44pt}{46pt}\selectfont}  % HUGE helvetica bold

%%%%%%%%%%%%%%%% two floating figures, side by side %%%%%%%%%%%%%%%
\newenvironment{2figures}[1]{\begin{figure}[#1] 
  \begin{center}
    \begin{tabular}{p{.47\textwidth}p{.47\textwidth}} }
 {  \end{tabular}
  \end{center} 
 \end{figure}
}

%%%%%%%%%%%%%%%%%%%%%% footnotes %%%%%%%%%%%%%%%%%%%%%
\def\footnoterule{\kern-3\p@
 \hrule width .4\columnwidth
 \kern 2.6\p@}
 
%%%%%%%%%%%% Environment makefntext %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\long\def\@makefntext#1{\parindent=\z@
\begin{list}{}%
   {\labelwidth1.5em\leftmargin\labelwidth% set global width
    \labelsep3pt%  horizontal separation between term and item
    \itemsep0pt%   vertical separation between two items
    \parsep0pt%    vertical separation two paragraphs in an item
    \topsep0pt%    vertical separation text/list
    \small}
%   \footnotesize}
    \item [\hfill $^{\mathrm{\@thefnmark)}}$] #1\end{list}}% ***** end of makefntext
 
%%%%%%%%%%%% Environment Figlist %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Figlist}[1]{% Give highest figure number as parameter
\vskip2mm\begin{center}{\bf FIGURE CAPTIONS}\end{center}
\begin{list}{\bf Fig.\hfill\arabic{figure} : }{\usecounter{figure}
    \settowidth{\labelwidth}{\bf Fig . #1 : }% define global width
    \leftmargin\labelwidth \labelsep0pt
    \itemsep0pt plus 0.1ex minus 0.1ex
    \parsep0pt plus 0.1ex minus 0.1ex
    \topsep\baselineskip}}%
{\end{list}\setcounter{figure}{0}% Reset figure counter
}% ***** end of environment{Figlist} ****

%%%%%%%%%%%% Environment CERNfig %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{CERNfig}{\begingroup % figures, one per page
\def\@makecaption##1##2{\hbox to\hsize{\hfil##1\hfil}}}%
{\endgroup}
% ***** end of environment{CERNfig} ****
 
%%%%%%%%%%%% Environment Tablist %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Tablist}[1]{% Give highest table number as parameter
\vskip2mm\begin{center}{\bf TABLE CAPTIONS}\end{center}
\begin{list}{\bf Tab.\hfill\arabic{table} : }{\usecounter{table}
    \settowidth{\labelwidth}{\bf Fig . #1 : }% define global width
    \leftmargin\labelwidth \labelsep0pt
    \itemsep0pt plus 0.1ex minus 0.1ex
    \parsep0pt plus 0.1ex minus 0.1ex
    \topsep\baselineskip}}%
{\end{list}\setcounter{table}{0}% Reset table counter
}% ***** end of environment{Tablist} ****
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% \begin{titlepage}
%     \cmsnote{yyyy-xxx}
%     \date{}
%     \title{ first  line \\
%             second line \\
%             etc...}
%     \author{B.B.Auth\Instref{xx} M.M.~Auth2\Bothref{I1}{A2}
%             C.D.user\Instref{yy} ...}
% \submitted{}
% \collaboration{}
% \conference{}
% \note{}
% \dedication{}
%     \Instfoot{xx}{text text}
%     \Instfoot{yy}{text text}
% \end{titlepage}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%% title page %%%%%%%%%%%%%%%%%%%%%%%%%5
\def\maketitle{% Dummy maketitle
\typeout{Dummy maketitle --- Use titlepage instead}}

% Definition of environment "titlepage"
\def\titlepage{\clearpage%
%JPP-or maybe pagestyle{plain}  ??
\setcounter{footnote}{0}\pagestyle{empty}}% End of \titlepage tag

% CMS NOTE header \cmsnote
\def\cmsnote#1{{Available on CMS information server
\hfill\Large\bf CMS NOTE #1} 
\begin{center}\includegraphics{cms_note.eps}\end{center}\vspace*{0mm}}

% CMS INTERNAL NOTE header \internalnote
\def\internalnote#1{{Available on CMS information server
\hfill\Large\bf CMS IN #1} 
\begin{center}\includegraphics{cms_in.eps}\end{center}}

% CMS CONFERENCE REPORT header \conferencereport
\def\conferencereport#1{{Available on CMS information server
\hfill\Large\bf CMS CR #1} 
\begin{center}\includegraphics{cms_cr.eps}\end{center}}

% Date (flushright)
\def\date#1{{\large\bf\hfill #1}}
%\def\date#1{\edef\@temp{#1}\ifx\@temp\@empty\def\@temp{\today}\fi
%\hbox to \hsize{\hskip123mm\hbox{\@temp}\hss}}
% Submitted{}
\def\submitted#1{\vskip1em\begin{center}#1\end{center}}
% collaboration{}
\def\collaboration#1{\vskip1em\begin{center}\bfseries\itshape#1\end{center}}
% conference{}
\def\conference#1{\vskip1em\begin{center}#1\end{center}}
% note{}
\def\note#1{\vskip1em\begin{center}#1\end{center}}
% dedication{}
\def\dedication#1{\vskip1em\begin{center}\it#1\end{center}}
% Title
\def\title#1{\vskip1.5cm\begin{center}\huge\sf#1\end{center}\vskip1.5em}
% Author
%\def\@makefnmark{\hbox to 0pt{$^{\@thefnmark)\,}$\hss}}
\def\@makefnmark{\hbox{$^{\@thefnmark)}$}}
\def\author#1{%% Treat the list of authors
\setcounter{footnote}{0}\def\@currentlabel{}%
\begingroup\def\thefootnote{\arabic{footnote}}
\def\@makefnmark{\hbox{$^{\rm\@thefnmark)}$}}
\global\@topnum\z@ \begin{center}{\lineskip.5em
\begin{tabular}[t]{c}#1\end{tabular}\par}
\end{center}\par\vskip1.5em\@thanks\endgroup}
%
\newenvironment{Authlist}{\center}{\endcenter}
% Abstract
\def\abstract{\begin{center}{\vskip1.5em\bf Abstract}\\[\baselineskip]%
\end{center}\quotation\noindent%
\setlength{\parindent}{0pt}%
\setlength{\parskip}{0.5\baselineskip}%
\ignorespaces}
\def\endabstract{\endquotation\par}
%
%%%%%%%%%%%% Institute definitions  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\@ifundefined{c@instfoot}{\newcounter{instfoot}}{}
\def\Iref#1{$^{\Inst{#1})}$}   \let\Instref=\Iref
\def\Inst#1{\@ifundefined{r@#1}{{\bf ??}}%
{\edef\@tempa{\@nameuse{r@#1}}\expandafter\@car\@tempa \@nil\null}}
%
%%AS If we found `Instfoot' inside `Authlist' env, we will changes the
%    formatting.
%
\def\Instfoot#1#2{\def\@temp{Authlist}%
\ifx\@temp\@currenvir
    \par {\small\it#2} \\[2ex]%
\else
    \refstepcounter{instfoot}\label{#1}%
    \xdef\@thefnmark{\arabic{instfoot}}\@footnotetext{#2}%
\fi
}
%
%%%%%%%%%%%% Anotation definitions  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%\@ifundefined{c@anotfoot}{\newcounter{anotfoot}}{}
\@ifundefined{mathrm}{\newcommand{\mathrm}[1]{{\rm#1}}}{}
\def\Aref#1{$^{\mathrm{#1})}$} \let\Anotref=\Aref
\def\Anotfoot#1#2{\xdef\@thefnmark{#1}\@footnotetext{#2}}
%
%%%%%%%%%%%% Anotation references   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\AAref#1#2{$^{\mathrm{#1,#2)}}$}       \let\AnotAnotref=\AAref
\def\IAref#1#2{$^{\Inst{#1},\mathrm{#2)}}$}\let\InstAnotref=\IAref
\def\IIref#1#2{$^{\Inst{#1},\Inst{#2})}$}  \let\InstInstref=\IIref
\def\IIIref#1#2#3{$^{\Inst{#1},\Inst{#2},\Inst{#3})}$}
\def\IIAref#1#2#3{$^{\Inst{#1},\Inst{#2},\mathrm{#3)}}$}
%%%%%%%%%%%% Annospec environment   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newenvironment{Annospec}[1]{% Give width for offset of text
\vskip2mm\bgroup
%\def\@makefnmark{\hbox{$^{\mathrm{\@thefnmark)}}$}}
\long\def\@makefntext##1{\parindent=\z@
\begin{list}{}%
   {\labelwidth=#1\leftmargin\labelwidth% set global width
    \labelsep3pt%  horizontal separation between term and item
    \itemsep0pt%   vertical separation between two items
    \parsep0pt%    vertical separation two paragraphs in an item
    \topsep0pt%    vertical separation text/list
    \small}
%   \footnotesize}
    \item [\hfill $^{\mathrm{\@thefnmark)}}$] ##1\end{list}}}% ***** end of makefntext
{\egroup}% ***** end of environment{Annospec} *****
 
 
% End of titlepage
\def\endtitlepage{%% Reset counters
\setcounter{footnote}{0}\let\titlepage\relax\vfill
%JPP-this is not the proper place for secounter{page}, must be in the tex file
%JPP-\newpage\setcounter{page}{1}\pagestyle{plain}\pagenumbering{arabic}%
\newpage\pagestyle{plain}\pagenumbering{arabic}%
\gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}

\RequirePackage{graphics}
 
% Local CERN stuff
 
\newcommand{\bra}[1]{\left\langle #1\right|} % <bra|
\newcommand{\ket}[1]{\left| #1\right\rangle} % |ket>
\newcommand{\braket}[2]{\left\langle#1 | #2\right\rangle} % <bra|ket>


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%    Start of additions (L. Taylor)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage[usenames]{pstcol}

\usepackage{epsfig}
\usepackage{pifont}
\usepackage{color}
\usepackage{multicol}   % used in the appendix of conventions

% \psdraft

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   General parameters / macros
% 
\parindent 0mm
\parskip   5pt plus 1pt minus 1pt
%
\newcommand{\FIXME}[1]{~{\magenta\sl{#1}}}%%%
\newcommand{\blahblah}{\FIXME{...type} \FIXME{some} \FIXME{explanatory} \FIXME{text} \FIXME{here...}}%
\newcommand{\Cafe}{Caf{\'{e}}}
%
%   New (more compact) itemize 
%   --------------------------
%
\newenvironment{myitemize}%
{\begin{list}%
{$\bullet$}%
{%
% Vertical spacing parameters
\setlength{\topsep}{0.5ex}%        
\setlength{\itemsep}{-\parsep}\addtolength{\itemsep}{0.15em}% 
\setlength{\partopsep}{0.5ex}%
%  Horizontal spacing parameters
\setlength{\labelwidth}{4.5ex}%
\setlength{\labelsep}{1.5ex}%
\setlength{\leftmargin}{6.0ex}%
\setlength{\rightmargin}{0.0ex}%
}}%
{\end{list}}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
%  Define new colours
% -------------------
%   
\definecolor{darkred}{rgb}{0.75,0.0,0.0}%
\definecolor{darkgreen}{rgb}{0.0,0.6,0.0}%
\definecolor{darkblue}{rgb}{0.0,0.0,0.6}%
% 
\definecolor{darkcyan}{rgb}{0.0,0.6,0.6}%
\definecolor{darkmagenta}{rgb}{0.6,0.0,0.6}%
\definecolor{darkyellow}{rgb}{0.6,0.6,0.0}%
% 
\definecolor{lightred}{rgb}{1.0,0.9,0.9}%
\definecolor{lightgreen}{rgb}{0.9,1.0,0.9}%
\definecolor{lightblue}{rgb}{0.9,0.9,1.0}%
% 
\definecolor{lightcyan}{rgb}{0.8,1.0,1.0}%
\definecolor{lightmagenta}{rgb}{1.0,0.8,1.0}%
\definecolor{lightyellow}{rgb}{1.0,1.0,0.8}%
% 
\definecolor{paleyellow}{rgb}{1.00,1.0,0.80}%
\definecolor{amber}{rgb}{1.0,0.8,0.0}%
\definecolor{darkamber}{rgb}{1.0,0.5,0.0}%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
%  Define short aliases for colours
% ---------------------------------
%   
\renewcommand{\black}{\color{black}}%
\renewcommand{\white}{\color{white}}%
%   
\renewcommand{\red}{\color{red}}%
\renewcommand{\green}{\color{green}}%
\renewcommand{\blue}{\color{blue}}%
%   
\renewcommand{\cyan}{\color{cyan}}%
\renewcommand{\magenta}{\color{magenta}}%
\renewcommand{\yellow}{\color{yellow}}%
%   
\newcommand{\darkred}{\color{darkred}}%
\newcommand{\darkgreen}{\color{darkgreen}}%
\newcommand{\darkblue}{\color{darkblue}}%
%   
\newcommand{\darkcyan}{\color{darkcyan}}%
\newcommand{\darkmagenta}{\color{darkmagenta}}%
\newcommand{\darkyellow}{\color{darkyellow}}%
%   
\newcommand{\lightred}{\color{lightred}}%
\newcommand{\lightgreen}{\color{lightgreen}}%
\newcommand{\lightblue}{\color{lightblue}}%
%   
\newcommand{\lightcyan}{\color{lightcyan}}%
\newcommand{\lightmagenta}{\color{lightmagenta}}%
\newcommand{\lightyellow}{\color{lightyellow}}%
%   
\newcommand{\paleyellow}{\color{paleyellow}}%
\newcommand{\amber}{\color{amber}}%
\newcommand{\darkamber}{\color{darkamber}}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Define auxiliary files (handles lists of task, deliverables, resources, etc.)
%
%  ``My Table of Contents'' (optionally use instead of default ``toc'' to have control)
%    -------------------- 
\newcommand{\mytableofcontents}{\clearpage\section*{Table of Contents}\@starttoc{mtc}}
%
%  ``Summaries''       
%    ---------
%
\newcommand{\summaryoftasks}{\clearpage\section{Level 3 Task Breakdown}\@starttoc{sot}}%
\newcommand{\summaryofdeliverables}{\clearpage\section{List of Deliverables}\@starttoc{sod}}%
\newcommand{\summaryofresources}{\clearpage\section{Summary of Resources}\@starttoc{sor}}%
%
%  ``Details''       
%    -------
%
\newcommand{\detailsoftasks}{\clearpage\section{Details of Tasks}\@starttoc{dot}}%
\newcommand{\detailsofdeliverables}{\clearpage\section{Details of Deliverables}\@starttoc{dod}}%
\newcommand{\detailsofresources}{\clearpage\section{Details of Resources}\@starttoc{dor}}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Basic commands for entering data (task group, task, subtask, deliverables, resources)
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Make \taskgroup command use for top-level sectioning (a bit like \part)
%
\newcounter{taskgroupcounter}%
\setcounter{taskgroupcounter}{0}%
%
\newcommand{\taskgroupline}[2]%   Format the line of text for various files
{\addcontentsline{#1}{section}%
{\mbox{\large\sffamily\bfseries{{\hspace*{\fill}Part \Roman{taskgroupcounter}:~~#2\hspace*{\fill}}}}}}%
%
\newcommand{\taskgroup}[1]%
{\refstepcounter{taskgroupcounter}%  Increment the counter
\clearpage
\vspace*{30mm}
\begin{center}
{\Huge\sffamily\bfseries{Part \Roman{taskgroupcounter}}}\\[20mm]
{\Huge\sffamily\bfseries{#1}}
\end{center}
\taskgroupline{toc}{#1}%
\taskgroupline{mtc}{#1}%
\taskgroupline{sot}{#1}%
\taskgroupline{sod}{#1}%
%\taskgroupline{sor}{#1}%
\taskgroupline{dot}{#1}%
\taskgroupline{dod}{#1}%
%\taskgroupline{dor}{#1}%
\clearpage
}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Make \taskgroupstar command for top-level sectioning (a bit like \part)
%
\newcommand{\taskgroupstarline}[2]%   Format the line of text for various files
{\addcontentsline{#1}{section}%
{\mbox{\large\sffamily\bfseries{{\hspace*{\fill}#2\hspace*{\fill}}}}}}%
%
\newcommand{\taskgroupstar}[1]%
{\clearpage
\vspace*{50mm}
\begin{center}
{\Huge\sffamily\bfseries{#1}}
\end{center}
\taskgroupstarline{toc}{#1}%
\taskgroupstarline{mtc}{#1}%
%\taskgroupstarline{sot}{#1}%
%\taskgroupstarline{sod}{#1}%
%\taskgroupstarline{sor}{#1}%
%\taskgroupstarline{dot}{#1}%
%\taskgroupstarline{dod}{#1}%
%\taskgroupstarline{dor}{#1}%
\clearpage
}%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Make \task and related commands
%
\newcommand{\taskline}[3]%   Format the line of text for various files
{\addcontentsline{#1}{section}{{\thesection}~~#2\hspace*{\fill}{\em{(#3)}}\hspace*{0.001mm}}}%
%
\newcommand{\task}[3]
{\typeout{=============================================================================}%
\typeout{----------> Processing task: #1}%  
%
\clearpage%
\section{#1\hspace*{\fill}{\em{(#2)}}\hspace*{0.001mm}}%
\def\@tasktext{{\thesection}~~#1}% put this in a variable for use by \resources
%
\taskline{mtc}{#1}{#2}%
\taskline{sot}{#1}{#2}%
\taskline{sod}{#1}{#2}%
%\taskline{sor}{#1}{#2}%
\taskline{dot}{#1}{#2}%
\taskline{dod}{#1}{#2}%
%\taskline{dor}{#1}{#2}%
%
{#3}\vskip -0.5ex plus  0.1ex minus 0.1ex \bigbreak% Write out the actual text
}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Make \subtask and related commands
%
\newcommand{\subtaskline}[3]%   Format the line of text for various files
{\addcontentsline{#1}{subsection}{{\thesubsection}~~#2}}%  Note: #3, the author, not written out (mostly undefined)
%
\newcommand{\subtask}[3]
{%---------------------------------
\typeout{-------------> Processing subtask: #1}%
%
\subsection{#1}%               Task name
%\subsection{#1\hspace*{\fill}{\em{(#2)}}\hspace*{0.001mm}}%               Task name and coordinator
\def\@subtasktext{{\thesubsection}~~#1}% put this in a variable for use by \resources
%
%\subtaskline{mtc}{#1}{#2}%
\subtaskline{sot}{#1}{#2}%
\subtaskline{sod}{#1}{#2}%
%\subtaskline{sor}{#1}{#2}%
\subtaskline{dot}{#1}{#2}%
\subtaskline{dod}{#1}{#2}%
%\subtaskline{dor}{#1}{#2}%
%
{#3}\vskip -0.5ex plus  0.1ex minus 0.1ex \bigbreak% Write out the actual text
}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Make \deliverable and related commands
%
\newcounter{thedeliverable}[subsection]  % {xxx} counter gets reset when [yyy] counter increments
\newcommand{\thedeliverablelabel}{\thesubsection-\alph{thedeliverable} }% N.B. leave this trailing space!!
\renewcommand{\thesubsubsection}{\thedeliverablelabel}%
%
% A stronger ``hspace'' to really force text right (a stupid kludge!!!)
\newcommand{\hrf}{\hspace*{\fill}\hspace*{\fill}\hspace*{\fill}\hspace*{\fill}\hspace*{\fill}}%
\newcommand{\hrrf}{\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf\hrf}%
%
\newcommand{\deliverableline}[3]%   Format the line of text for various files
{\addcontentsline{#1}{subsubsection}{\protect{{{\bf{\thedeliverablelabel}}~~#2~~\hrrf[#3]\mbox{~~~}}}}}%
%
\newcommand{\deliverable}[6]%
{%---------------------------------
\typeout{----------------> Processing deliverable: #1}%
%
\refstepcounter{thedeliverable}%  Increment the counter
\def\@deliverabletext{#1}% put this in a variable for use by \resources
%
%\deliverableline{mtc}{#1}{#4}%
%\deliverableline{sot}{#1}{#4}%
\deliverableline{sod}{#1}{#4}%
%\deliverableline{sor}{#1}{#4}%
\deliverableline{dot}{#1}{#4}%
\deliverableline{dod}{#1}{#4}%
%\deliverableline{dor}{#1}{#4}%
%
%-----------------------------------------------------------------------
%
%  This is what goes in the main body of the document
%
\begin{tabular}{|p{0.14\textwidth}p{0.81\textwidth}|}\hline
{{{\bf{Deliverable:}}}}     &{\bf{\thedeliverablelabel~~#1}}  \\[-0.001ex] %
{\em{Description:}}         & #5        \\ %
{\em{Responsible:}}         & #2        \\ %
{\em{Client(s):}}           & #3        \\ %
{\em{End Date:}}            & #4        \\ %
{\em{Risks/Constraints:}}   & #6        \\ %
\hline%
\end{tabular}%
%
%\vspace*{-2.0ex plus 0.5ex minus 0.5ex}% 
%\bigbreak
}%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Make \resource and related commands
%
%

\providecommand{\XXXXresourceline}[8]%   Format the line of text for various files
{
\addtocontents{#1}{%
 #2 %
     ,  %
 #3  ,  %
 #4  ,  %
 #5  ,  %
 #6  ,  %
 #7  ,  %
 #8  ,  %
% #9  ,  % this is the resource description
\@deliverabletext , %
\@tasktext , %
\newline%
}}%


\newcommand{\resource}[7]
{%
\typeout{------------------->   Processing resource: #7}%
%  
\mbox{~}\\% finish previous line (in the \deliverable table)
{\em{Resource:}} & 
%\noindent%
\makebox[0.25\textwidth][l]{#1 - #2:}%
\makebox[0.08\textwidth][l]{{\bf{#4}}~~FTE}
\makebox[0.14\textwidth][l]{(#5 available).}%
\makebox[0.32\textwidth][l]{#7.}%
%
%\resourceline{dor}{\thedeliverablelabel}{#1}{#2}{#3}{#4}{#5}{#6}%%%%%% {#7}
%
\addtocontents{dor}{%
 \thedeliverablelabel %
     ,  %
 #1  ,  %
 #2  ,  %
 #3  ,  %
 #4  ,  %
 #5  ,  %
 #6  ,  %
% #7  ,  % this is the resource description
\@deliverabletext , %
\@tasktext , %
\newline%
}%
%
}%














%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Command to make a table of resources (needs work...)
%

%\newcommand{\listofresources}
%{%----------------------------------------------------------
%\section*{Tables of Core Personnel Requirements (in FTE-years)}
%
%\vspace*{30mm}
%
%{\Large{%
%\noindent{\bf{Notes pertaining to all the following tables:}}
%\begin{enumerate}
%   \item    CCS data are entered for all tasks but numbers are still
%            subject to refinement.
%   \item    Tier 0/1/2 operating personnel are not included. 
%   \item    PRS personnel are physicists and are not included in this table.
%   \item    TriDAS online software data are still under construction;
%            all numbers here are preliminary.
%   \item    Currently available personnel are shown in parentheses (N.B. very preliminary)
%   \item    {\em\red{Red italic}} denotes a shortfall in resources
%   \item    {\em\green{Green italic}} denotes an excess of resources
%\end{enumerate}
%}}
%
%\@starttoc{rsc}%         
%}%----------------------------------------------------------


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  End of additions (L. Taylor)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\endinput

%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}


































